==> lms-1.6.1+libs.tar.gz: lms/modules/tarifflist.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tarifflist.php,v 1.27.2.2 2005/05/20 11:44:43 kondi Exp $
 */

$layout['pagetitle'] = trans('Subscription List');

$tarifflist = $LMS->GetTariffList();

$listdata['total'] = $tarifflist['total'];
$listdata['totalincome'] = $tarifflist['totalincome'];
$listdata['totalusers'] = $tarifflist['totalusers'];
$listdata['totalcount'] = $tarifflist['totalcount'];
$listdata['totalassignmentcount'] = $tarifflist['totalassignmentcount'];

unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalusers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);

$SMARTY->assign('tarifflist',$tarifflist);
$SMARTY->assign('listdata',$listdata);
$SMARTY->display('tarifflist.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/tarifflist.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tarifflist.php,v 1.30 2005/05/26 11:33:03 alec Exp $
 */

$layout['pagetitle'] = trans('Subscription List');

$tarifflist = $LMS->GetTariffList();

$listdata['total'] = $tarifflist['total'];
$listdata['totalincome'] = $tarifflist['totalincome'];
$listdata['totalcustomers'] = $tarifflist['totalcustomers'];
$listdata['totalcount'] = $tarifflist['totalcount'];
$listdata['totalassignmentcount'] = $tarifflist['totalassignmentcount'];

unset($tarifflist['total'],$tarifflist['totalincome'],$tarifflist['totalcustomers'],$tarifflist['totalcount'],$tarifflist['totalassignmentcount']);

$SMARTY->assign('tarifflist',$tarifflist);
$SMARTY->assign('listdata',$listdata);
$SMARTY->display('tarifflist.html');

?>
